require("AnAL")

function love.load()
	--load graphics, sounds, and images
	love.graphics.setColor( 100, 100, 100, 255 );
	love.graphics.setBackgroundColor(25,25,25);
	love.graphics.setMode(600,600,false);  --set to TRUE for FULL SCREEN
	love.graphics.setColorMode("replace");
	img_background = love.graphics.newImage("IMAGES/background.png");
	sound_awesome = love.audio.newSource("victory.mp3", "static");
	sound_hit = love.audio.newSource("hit.wav", "static");
	sound_miss = love.audio.newSource("miss.wav", "static");
    --list of all possible words
    words = {
    	{'b', 'a', 'b', 'y'},
		{'g', 'i', 'r', 'l'},
		{'w', 'i', 'g', 'g', 'l', 'e'},
		{'d', 'a', 'i', 's', 'y'}};
    --list of active words the user can type and their heights
    activeWords = {};
    activeHeight = {};
    numActiveWords = 0;
    --add the first word to the screen
    addActiveWord();
    --the letters of the current word the user has already typed (ex: 'r''a''i'- for 'rainbow')
    userWord = {};
    --the rest of the active word being typed (ex:-'n''b''o''w' - for 'rainbow')
    currentWord = {};
end

function love.update(dt)
	--lower each word
	for i = 1, table.getn(activeWords), 1 do
		activeHeight[i] = activeHeight[i];-- + 1;
		if activeHeight[i] >= 600 then
			love.audio.play(sound_miss);
			table.remove(activeWords, i);
			numActiveWords = numActiveWords - 1;
		end
	end

	--make sure there are 3 words
	if(table.getn(activeWords) < 3) then
		addActiveWord();
	end
end

function love.draw()
	--draw the background
	love.graphics.draw(img_background, 0, 0);
	--draw each active word @ it's correct height
	for i=1, table.getn(activeWords), 1 do
		printArray(activeWords[i], i*30, activeHeight[i]);
	end
	--alert if no active word
	if(table.getn(currentWord)==0) then
		love.graphics.printf("no current word", 400, 400, 100, "center");
	end
	
	--print debugging items
	printArray(currentWord, 300, 340);
	printArray(userWord, 300, 350);
	love.graphics.printf("#ACTIVE = "..numActiveWords, 200, 200, 100, "center");
	love.graphics.printf(table.getn(activeWords), 200, 210, 100, "center");
	
end

function love.keypressed(key, unicode)
	--GET LETTER ENTERDED
	letter = string.char(unicode);
	--IF THERE IS A CURRENT WORD BEING WORKED ON
	if(table.getn(currentWord)~=0) then
		--IF ENTERED LETTER MATCHES NEXT LETTER 	
		if(letter == currentWord[1]) then
			--move letter from currentWord to userWord
			table.remove(currentWord, 1);
			table.insert(userWord, letter);
			--if that completes the current word - play a tune!
			if(table.getn(currentWord)==0) then
				love.audio.play(sound_hit);
			end
		end
	--NO CURRENT WORD
	else
	--check if the character matches any first letters of available words
		for i = 1, table.getn(activeWords), 1 do
			nextLetter = activeWords[i][1];
			--if matches - take word out of active, put into current, and move first letter to userWord
			if(nextLetter==letter) then
				table.insert(userWord, letter);
				currentWord = activeWords[i];
				table.remove(activeWords, i);
				table.remove(currentWord, 1);
			end
		end
	end
end
--a function that takes a word from the game 'dictionary' and puts it into activeWords
function addActiveWord()
	table.insert(activeWords, words[1]);
    table.insert(activeHeight, 0);
    table.remove(words, 1);
    numActiveWords = numActiveWords + 1;
    love.graphics.printf("ADDED WORD", 300, 300, 100, "center");

end

--prints an array of characters to the screen at xy position
function printArray(word, x, y)

      for i,v in ipairs(word) do
        love.graphics.printf(v, x+i*5, y, 100, "center");
      end
end
